@@ -44,4 +44,10 @@ build <- function(...)
 	UseMethod("build")
 
 add <- function(...)
-	UseMethod("add")
\ No newline at end of file
+	UseMethod("add")
+
+sigmoid <- function(x) 1/(1 + exp(-x))
+
+dsigmoid <- function(x) sigmoid(x) * (1 - sigmoid(x))
+
+d2sigmoid <- function(x) dsigmoid(x) * (1 - 2 * sigmoid(x))
